# New Release Procedure
  1. Add changelog to README.md
  1. Make a comit with the form firefox_newuser-$NEWVERSION$
  1. git push
  1. Create a new tag increasing its version
  1. Change to myportage overlay and update ebuild
  1. Make a comit with the form firefox_newuser-$NEWVERSION$
  1. git push

